==> FairMongo-4.3.1.tar.gz: FairMongo-4.3.1/FCM/Jarticle/jVirtualWorld.py <==
from F import LIST, DICT
from F.LOG import Log
from FCM.MCCore import MCCore

Log = Log("jVirtualWorld")

COLLECTION_NAME = "virtual_worlds"

""" Master Class to work with Companies Collection """
class jVirtualWorld(MCCore):

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.connect(COLLECTION_NAME)

    def add_virtual_world(self, list_of_virtual_worlds):
        for item in list_of_virtual_worlds:
            print(item)
            self.insert_record(item)

    def find_world_by_ticker(self, ticker):
        world_record = self.base_query({'symbol': ticker})
        if world_record:
            single_record = LIST.get(0, world_record, False)
            return single_record
        return False

    def find_ticker_by_world(self, worldName, tickerOnly=False):
        company_record = self.base_query({'name': worldName})
        if company_record:
            single_record = LIST.get(0, company_record, False)
            if tickerOnly:
                ticker = DICT.get("symbol", single_record)
                return ticker
            return single_record
        return False

    def get_world_id_for_ticker(self, ticker):
        world = self.find_world_by_ticker(ticker)
        if world:
            id = DICT.get("_id", world)
            return id
        return False

    def get_list_of_all_worlds(self):
        all_ = self.base_query({}, page=False, limit=False)
        return all_


if __name__ == '__main__':
    jc = jVirtualWorld()
    record = jc.get_list_of_all_worlds()
    print(record)

==> FairMongo-4.3.2.tar.gz: FairMongo-4.3.2/FCM/Jarticle/jVirtualWorld.py <==
from F import LIST, DICT
from F.LOG import Log
from FCM.MCCore import MCCore

Log = Log("jVirtualWorld")

COLLECTION_NAME = "virtual_worlds"

""" Master Class to work with Companies Collection """
class jVirtualWorld(MCCore):

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.connect(COLLECTION_NAME)

    def add_virtual_world(self, list_of_virtual_worlds):
        for item in list_of_virtual_worlds:
            print(item)
            self.insert_record(item)

    def find_world_by_ticker(self, ticker):
        ticker = str(ticker).upper()
        world_record = self.base_query({'symbol': ticker})
        if world_record:
            single_record = LIST.get(0, world_record, False)
            return single_record
        return False

    def find_ticker_by_world(self, worldName, tickerOnly=False):
        company_record = self.base_query({'name': worldName})
        if company_record:
            single_record = LIST.get(0, company_record, False)
            if tickerOnly:
                ticker = DICT.get("symbol", single_record)
                return ticker
            return single_record
        return False

    def get_world_id_for_ticker(self, ticker):
        world = self.find_world_by_ticker(ticker)
        if world:
            id = DICT.get("_id", world)
            return id
        return False

    def get_list_of_all_worlds(self, page=False, limit=False):
        all_ = self.base_query({}, page=page, limit=limit)
        return all_


if __name__ == '__main__':
    jc = jVirtualWorld()
    record = jc.get_list_of_all_worlds()
    print(record)
